@@ -13,7 +13,7 @@ use HTML::Scrubber     ();
 use Lingua::JA::Regular::Unicode ();
 use Lingua::JA::Dakuon ();
 
-our $VERSION   = '0.21';
+our $VERSION   = '0.22';
 our @EXPORT    = qw();
 our @EXPORT_OK = qw(nfkc nfkd nfc nfd decode_entities strip_html
 alnum_z2h alnum_h2z space_z2h space_h2z katakana_z2h katakana_h2z
@@ -21,8 +21,8 @@ katakana2hiragana hiragana2katakana wave2tilde tilde2wave
 wavetilde2long wave2long tilde2long fullminus2long dashes2long
 drawing_lines2long unify_long_repeats nl2space unify_long_spaces
 unify_whitespaces unify_nl trim ltrim rtrim old2new_kana old2new_kanji
-tab2space remove_controls dakuon_normalize handakuon_normalize
-all_dakuon_normalize);
+tab2space remove_controls remove_spaces dakuon_normalize
+handakuon_normalize all_dakuon_normalize);
 
 our %EXPORT_TAGS = ( all => [ @EXPORT, @EXPORT_OK ] );
 
@@ -122,6 +122,7 @@ sub unify_nl             { local $_ = shift; return unless defined $_; s/\x{000D
 sub tab2space            { local $_ = shift; return unless defined $_; tr/\x{0009}/\x{0020}/; $_; }
 sub old2new_kana         { local $_ = shift; return unless defined $_; tr/ゐヰゑヱ/いイえエ/; s/ヸ/イ\x{3099}/g; s/ヹ/エ\x{3099}/g; $_; }
 sub remove_controls      { local $_ = shift; return unless defined $_; tr/\x{0000}-\x{0008}\x{000B}\x{000C}\x{000E}-\x{001F}\x{007F}-\x{009F}//d; $_; }
+sub remove_spaces        { local $_ = shift; return unless defined $_; tr/\x{0020}\x{3000}//d; $_; }
 
 sub old2new_kanji
 {
@@ -219,6 +220,7 @@ The following options are available:
   old2new_kanji          亞逸鬭                 亜逸闘
   tab2space              (tab)(tab)             (space)(space)
   remove_controls        あ\x{0000}あ           ああ
+  remove_spaces          (space)あ(space)あ(space)  ああ
   dakuon_normalize       さ\x{3099}             ざ
   handakuon_normalize    は\x{309A}             ぱ
   all_dakuon_normalize   さ\x{3099}は\x{309A}   ざぱ
@@ -248,16 +250,19 @@ Note that this option unifies only SPACE(U+0020) and IDEOGRAPHIC SPACE(U+3000).
 
 =head2 remove_controls
 
-Note that this option does not remove the following chars:
+Note that this option does not remove the following characters:
 
   CHARACTER TABULATION
   LINE FEED
   CARRIAGE RETURN
 
+=head2 remove_spaces
+
+  Note that this option removes only SPACE(U+0020) and IDEOGRAPHIC SPACE(U+3000).
 
 =head2 unify_whitespaces
 
-This option converts the following chars into SPACE(U+0020).
+This option converts the following characters into SPACE(U+0020).
 
   LINE TABULATION
   FORM FEED
@@ -281,7 +286,7 @@ This option converts the following chars into SPACE(U+0020).
   NARROW NO-BREAK SPACE
   MEDIUM MATHEMATICAL SPACE
 
-Note that this does not convert the following chars:
+Note that this does not convert the following characters:
 
   CHARACTER TABULATION
   LINE FEED
